@@ -12,7 +12,7 @@ namespace QTest {
         QByteArray ba = "Kolab::cDateTime(";
         ba += QByteArray::number(dt.year()) + ", " + QByteArray::number(dt.month())+ ", " + QByteArray::number(dt.day()) + ", ";
         ba += QByteArray::number(dt.hour()) + ", " + QByteArray::number(dt.minute()) + ", " + QByteArray::number(dt.second())+ ", ";
-        ba += QString(dt.isUTC()?QString("UTC"):QString("TZ: "+QString::fromStdString(dt.timezone()))).toLatin1();
+        ba += dt.isUTC()?QByteArray("UTC"):QByteArray("TZ: "+QByteArray(dt.timezone().c_str()));
         ba += ")";
         return qstrdup(ba.data());
     }
@@ -32,9 +32,9 @@ namespace QTest {
     char *toString(const Kolab::Attendee &a)
     {
         QByteArray ba = "Kolab::Attendee(";
-        ba += QString::fromStdString(a.contact().email()).toLatin1() + ", " + QString::fromStdString(a.contact().name()).toLatin1()+ ", " + 
-        QByteArray::number(a.partStat()) + ", " + QByteArray::number(a.role())  + ", " + QByteArray::number(a.rsvp())  + ", " + 
-        QString::fromStdString(a.contact().uid()).toLatin1();
+        ba += QByteArray(a.contact().email().c_str()) + ", " + QByteArray(a.contact().name().c_str())+ ", " +
+        QByteArray::number(a.partStat()) + ", " + QByteArray::number(a.role())  + ", " + QByteArray::number(a.rsvp())  + ", " +
+        QByteArray(a.contact().uid().c_str());
         ba += ")";
         return qstrdup(ba.data());
     }
@@ -54,7 +54,7 @@ namespace QTest {
     char *toString(const std::string &s)
     {
         QByteArray ba = "string(";
-        ba += QString::fromStdString(s).toLatin1();
+        ba += QByteArray(s.c_str());
         ba += ")";
         return qstrdup(ba.data());
     }
@@ -104,8 +104,8 @@ namespace QTest {
     char *toString(const Kolab::Attachment &a)
     {
         QByteArray ba = "Kolab::Attachment(";
-        ba += QString::fromStdString(a.uri()).toLatin1() + ", " + QString::fromStdString(a.mimetype()).toLatin1()+ ", " + 
-        QString::fromStdString(a.label()).toLatin1();
+        ba += QByteArray(a.uri().c_str()) + ", " + QByteArray(a.mimetype().c_str())+ ", " +
+        QByteArray(a.label().c_str());
         ba += ")";
         return qstrdup(ba.data());
     }
@@ -125,9 +125,9 @@ namespace QTest {
     char *toString(const Kolab::ContactReference &a)
     {
         QByteArray ba = "Kolab::ContactReference(";
-        ba += QString::fromStdString(a.email()).toLatin1()+ ", ";
-        ba += QString::fromStdString(a.name()).toLatin1()+ ", ";
-        ba += QString::fromStdString(a.uid()).toLatin1();
+        ba += QByteArray(a.email().c_str())+ ", ";
+        ba += QByteArray(a.name().c_str())+ ", ";
+        ba += QByteArray(a.uid().c_str());
         ba += ")";
         return qstrdup(ba.data());
     }
@@ -147,9 +147,9 @@ namespace QTest {
     char *toString(const Kolab::Alarm &a)
     {
         QByteArray ba = "Kolab::Alarm(";
-        ba += QByteArray::number(a.type()) + "\n " + QString::fromStdString(a.summary())+ "\n " + 
-        QString::fromStdString(a.text())+"\n " +toString(a.duration()) + "\n " + QByteArray::number(a.numrepeat())+  "\n " + toString(a.start()) + "\n " +
-        toString(a.relativeStart())  + "\n " +  QByteArray::number(a.relativeTo()) + "\n " + toString(a.audioFile()) +  "\n " + toString(a.attendees()) + "\n ";
+        ba += QByteArray::number(a.type()) + "\n " + QByteArray(a.summary().c_str())+ "\n " +
+        QByteArray(a.text().c_str())+"\n " +QByteArray(toString(a.duration())) + "\n " + QByteArray::number(a.numrepeat())+  "\n " + QByteArray(toString(a.start())) + "\n " +
+        QByteArray(toString(a.relativeStart())) + "\n " + QByteArray::number(a.relativeTo()) + "\n " + QByteArray(toString(a.audioFile())) +  "\n " + QByteArray(toString(a.attendees())) + "\n ";
         ba += ")";
         return qstrdup(ba.data());
     }
@@ -169,8 +169,8 @@ namespace QTest {
     char *toString(const Kolab::Related &a)
     {
         QByteArray ba = "Kolab::Related(";
-        ba += QString::fromStdString(a.text()).toLatin1()+ "\n " + 
-        QString::fromStdString(a.uri()).toLatin1()+"\n " +
+        ba += QByteArray(a.text().c_str())+ "\n " +
+        QByteArray(a.uri().c_str())+"\n " +
         QByteArray::number(a.relationTypes()) + "\n " +
         QByteArray::number(a.type()) + "\n ";
         ba += ")";
@@ -192,9 +192,9 @@ namespace QTest {
     char *toString(const Kolab::Affiliation &a)
     {
         QByteArray ba = "Kolab::Affiliation(";
-        ba += QString::fromStdString(a.organisation()).toLatin1()+ "\n " + 
-        QString::fromStdString(a.logo())+"\n " + "\n " + toString(a.roles())+  "\n " + toString(a.relateds()) + "\n " +
-        toString(a.addresses())  + "\n ";
+        ba += QByteArray(a.organisation().c_str())+ "\n " +
+        QByteArray(a.logo().c_str()) + "\n " + "\n " + QByteArray(toString(a.roles())) + "\n " + QByteArray(toString(a.relateds())) + "\n " +
+        QByteArray(toString(a.addresses())) + "\n ";
         ba += ")";
         return qstrdup(ba.data());
     }
